.. _clean:

================
Backups cleaning
================

This page describes how the process of cleaning the backups works.

.. contents:: Table of Contents
   :depth: 3


Remove a specific backup
------------------------

Not implemented yet in virt-backup. Removing a backup needs to be done manually, by removing the files.


Clean outdated backups
----------------------

To be documented.

For more details about the retention period, for now please read this comment in a github issue: https://github.com/aruhier/virt-backup/issues/38#issuecomment-659590425
